/*
 * clock.h - part of USBasp
 *
 * Autor..........: Thomas Fischl <tfischl@gmx.de>
 * Description....: Provides functions for timing/waiting
 * Licence........: GNU GPL v2 (see Readme.txt)
 * Creation Date..: 2005-02-23
 * Last change....: 2006-11-16
 */

#ifndef __clock_h_included__
#define	__clock_h_included__

#define TIMERVALUE      TCNT0
//#define CLOCK_T_320us	80  // @ 16MHz
#define CLOCK_T_320us	(uint8_t)(F_CPU * 320 / 1000000 / 64)

// delay 64 * count clock , max 320us
static inline void clockDelay(uint8_t count) {
	uint8_t starttime = TIMERVALUE;
	while ((uint8_t) (TIMERVALUE - starttime) < count) {
		wdt_reset();
	}
}

#ifdef __AVR_ATmega8__
#define TCCR0B  TCCR0
#endif

/* set prescaler to 64 */
#define clockInit()  TCCR0B = (3 << CS00);

/* wait time * 320 us */
void clockWait(uint8_t time);

/* ISP SCK speed identifiers */
#define USBASP_ISP_SCK_AUTO   0
#define USBASP_ISP_SCK_0_5    1   /* 500 Hz */
#define USBASP_ISP_SCK_1      2   /*   1 kHz */
#define USBASP_ISP_SCK_2      3   /*   2 kHz */
#define USBASP_ISP_SCK_4      4   /*   4 kHz */
#define USBASP_ISP_SCK_8      5   /*   8 kHz */
#define USBASP_ISP_SCK_16     6   /*  16 kHz */
#define USBASP_ISP_SCK_32     7   /*  32 kHz */

/* 8 MHz base definition */
#define USBASP_ISP_SCK_62_5   8   /* 62.5 kHz */
#define USBASP_ISP_SCK_125    9   /* 125 kHz  */
#define USBASP_ISP_SCK_250    10  /* 250 kHz  */
#define USBASP_ISP_SCK_500    11  /* 500 kHz  */
#define USBASP_ISP_SCK_1000   12  /* 1.0MHz  */
#define USBASP_ISP_SCK_2000   13  /* 2.0MHz  */
#define USBASP_ISP_SCK_4000   14  /* 4.0MHz  */
#define USBASP_ISP_SCK_8000   15  /* 8.0MHz  */

/* 12 MHz base definition */
#define USBASP_ISP_SCK_93_75  8   /* 93.75 kHz */
#define USBASP_ISP_SCK_187_5  9   /* 187.5 kHz */
#define USBASP_ISP_SCK_375    10  /* 375 kHz  */
#define USBASP_ISP_SCK_750    11  /* 750 kHz  */
#define USBASP_ISP_SCK_1500   12  /* 1.5 MHz */
#define USBASP_ISP_SCK_3000   13  /* 3.0 MHz */
#define USBASP_ISP_SCK_6000   14  /* 6.0 MHz */

#endif /* __clock_h_included__ */
